@@ -1,48 +1,4 @@
 package Mojo::APNS;
-
-=head1 NAME
-
-Mojo::APNS - Apple Push Notification Service for Mojolicious
-
-=head1 VERSION
-
-0.07
-
-=head1 DESCRIPTION
-
-This module provides an API for sending messages to an iPhone using Apple Push
-Notification Service.
-
-This module does not support password protected SSL keys.
-
-NOTE! This module will segfault if you swap L</key> and L</cert> around.
-
-=head1 SYNOPSIS
-
-  use Mojo::APNS;
-
-  my $apns = Mojo::APNS->new(
-              key => '/path/to/apns-dev-key.pem',
-              cert => '/path/to/apns-dev-cert.pem',
-              sandbox => 0,
-            );
-
-  $apns->on(drain => sub { $apns->loop->stop; })
-  $apns->send(
-    "c9d4a07c fbbc21d6 ef87a47d 53e16983 1096a5d5 faa15b75 56f59ddd a715dff4",
-    "New cool stuff!",
-    badge => 2,
-  );
-
-  $apns->on(feedback => sub {
-    my($apns, $feedback) = @_;
-    warn "$feedback->{device} rejected push at $feedback->{ts}";
-  });
-
-  $apns->ioloop->start;
-
-=cut
-
 use feature 'state';
 use Mojo::Base 'Mojo::EventEmitter';
 use Mojo::JSON 'encode_json';
@@ -50,56 +6,7 @@ use Mojo::IOLoop;
 use constant FEEDBACK_RECONNECT_TIMEOUT => 5;
 use constant DEBUG => $ENV{MOJO_APNS_DEBUG} ? 1 : 0;
 
-our $VERSION = '0.07';
-
-=head1 EVENTS
-
-=head2 error
-
-Emitted when an error occur between client and server.
-
-=head2 drain
-
-Emitted once all messages have been sent to the server.
-
-=head2 feedback
-
-  $self->on(feedback => sub {
-    my($self, $data) = @_;
-    # ...
-  });
-
-This event is emitted once a device has rejected a notification. C<$data> is a
-hash-ref:
-
-  {
-    ts => $rejected_epoch_timestamp,
-    device => $device_token,
-  }
-
-Once you start listening to "feedback" events, a connection will be made to
-Apple's push notification server which will then send data to this callback.
-
-=head1 ATTRIBUTES
-
-=head2 cert
-
-Path to apple SSL certificate.
-
-=head2 key
-
-Path to apple SSL key.
-
-=head2 sandbox
-
-Booleand true for talking with "gateway.sandbox.push.apple.com" instead of
-"gateway.push.apple.com". Default is true.
-
-=head2 ioloop
-
-Holds a L<Mojo::IOLoop> object.
-
-=cut
+our $VERSION = '1.00';
 
 has key     => '';
 has cert    => '';
@@ -112,15 +19,6 @@ has _gateway_address => sub {
   $_[0]->sandbox ? 'gateway.sandbox.push.apple.com' : 'gateway.push.apple.com';
 };
 
-=head1 METHODS
-
-=head2 on
-
-Same as L<Mojo::EventEmitter/on>, but will also set up feedback connection if
-the event is L</feedback>.
-
-=cut
-
 sub on {
   my ($self, $event, @args) = @_;
 
@@ -161,40 +59,12 @@ sub _connected_to_feedback_deamon_cb {
   };
 }
 
-=head2 send
-
-  $self->send($device, $message, %args);
-  $self->send($device, $message, %args, $cb);
-
-Will send a C<$message> to the C<$device>. C<%args> is optional, but can contain:
-
-C<$cb> will be called when the messsage has been sent or if it could not be
-sent. C<$error> will be false on success.
-
-    $cb->($self, $error);
-
-=over 4
-
-=item * badge
-
-The number placed on the app icon. Default is 0.
-
-=item * sound
-
-Default is "default".
-
-=item * Custom arguments
-
-=back
-
-=cut
-
 sub send {
   my $cb = ref $_[-1] eq 'CODE' ? pop : \&_default_handler;
   my ($self, $device_token, $message, %args) = @_;
   my $data = {};
 
-  $data->{aps} = {alert => $message, badge => int(delete $args{badge} || 0),};
+  $data->{aps} = {alert => $message, badge => int(delete $args{badge} || 0)};
 
   if (defined(my $sound = delete $args{sound})) {
     $data->{aps}{sound} = $sound if length $sound;
@@ -219,7 +89,7 @@ sub send {
   warn "[APNS:$device_token] <<< $message\n" if DEBUG;
 
   $self->once(drain => sub { $self->$cb('') });
-  $self->_write([chr(0), pack('n', 32), pack('H*', $device_token), pack('n', length $message), $message,]);
+  $self->_write([chr(0), pack('n', 32), pack('H*', $device_token), pack('n', length $message), $message]);
 }
 
 sub _connect {
@@ -240,9 +110,9 @@ sub _connect {
     tls_cert => $self->cert,
     tls_key  => $self->key,
     sub {
-      my ($ioloop, $error, $stream) = @_;
+      my ($ioloop, $err, $stream) = @_;
 
-      $error and return $self->emit(error => "$type: $error");
+      $err and return $self->emit(error => "$type: $err");
       $stream->on(close   => sub { delete $self->{"${type}_stream_id"} });
       $stream->on(error   => sub { $self->emit(error => "$type: $_[1]") });
       $stream->on(drain   => sub { $self->emit('drain'); });
@@ -283,15 +153,184 @@ sub _write {
 sub DESTROY {
   my $self = shift;
   my $ioloop = $self->ioloop or return;
+  my $id;
 
-  if (my $id = $self->{gateway_id}) {
-    $ioloop->remove($id);
-  }
-  if (my $id = $self->{feedback_id}) {
-    $ioloop->remove($id);
-  }
+  $ioloop->remove($id) if $id = $self->{gateway_id};
+  $ioloop->remove($id) if $id = $self->{feedback_id};
 }
 
+1;
+
+=encoding utf8
+
+=head1 NAME
+
+Mojo::APNS - Apple Push Notification Service for Mojolicious
+
+=head1 VERSION
+
+1.00
+
+=head1 DESCRIPTION
+
+This module provides an API for sending messages to an iPhone using Apple Push
+Notification Service.
+
+This module does not support password protected SSL keys.
+
+NOTE! This module will segfault if you swap L</key> and L</cert> around.
+
+=head1 SYNOPSIS
+
+=head2 Script
+
+  use Mojo::Base -strict;
+  use Mojo::APNS;
+
+  my $device_id = shift @ARGV;
+  my $apns = Mojo::APNS->new(
+    cert    => "/path/to/apns-dev-cert.pem",
+    key     => "/path/to/apns-dev-key.pem",
+    sandbox => 0,
+  );
+
+  # Emulate a blocking request with Mojo::IOLoop->start() and stop()
+  $apns->send($device_id, "Hey there!", sub { shift->ioloop->stop })->ioloop->start;
+
+=head2 Web application
+
+  use Mojolicious::Lite;
+  use Mojo::APNS;
+
+  # set up a helper that holds the Mojo::APNS object
+  helper apns => sub {
+    state $apns
+      = Mojo::APNS->new(
+          cert    => "/path/to/apns-dev-cert.pem",
+          key     => "/path/to/apns-dev-key.pem",
+          sandbox => 0,
+        );
+  };
+
+  # send a notification
+  post "/notify" => sub {
+    my $c         = shift;
+    my $device_id = "c9d4a07c fbbc21d6 ef87a47d 53e16983 1096a5d5 faa15b75 56f59ddd a715dff4";
+
+    $c->delay(
+      sub {
+        my ($delay) = @_;
+        $c->apns->send($device_id, "hey there!", $delay->begin);
+      },
+      sub {
+        my ($delay, $err) = @_;
+        return $c->reply->exception($err) if $err;
+        return $c->render(text => "Message was sent!");
+      }
+    );
+  };
+
+  # listen for feedback events
+  app->apns->on(
+    feedback => sub {
+      my ($apns, $feedback) = @_;
+      warn "$feedback->{device} rejected push at $feedback->{ts}";
+    }
+  );
+
+  app->start;
+
+=head1 EVENTS
+
+=head2 error
+
+  $self->on(error => sub { my ($self, $err) = @_; });
+
+Emitted when an error occurs between client and server.
+
+=head2 drain
+
+  $self->on(drain => sub { my ($self) = @_; });
+
+Emitted once all messages have been sent to the server.
+
+=head2 feedback
+
+  $self->on(feedback => sub { my ($self, $data) = @_; });
+
+This event is emitted once a device has rejected a notification. C<$data> is a
+hash-ref:
+
+  {
+    ts     => $rejected_epoch_timestamp,
+    device => $device_token,
+  }
+
+Once you start listening to "feedback" events, a connection will be made to
+Apple's push notification server which will then send data to this callback.
+
+=head1 ATTRIBUTES
+
+=head2 cert
+
+  $self = $self->cert("/path/to/apns-dev-cert.pem");
+  $path = $self->cert;
+
+Path to apple SSL certificate.
+
+=head2 key
+
+  $self = $self->key("/path/to/apns-dev-key.pem");
+  $path = $self->key;
+
+Path to apple SSL key.
+
+=head2 sandbox
+
+  $self = $self->sandbox(0);
+  $bool = $self->sandbox;
+
+Boolean true for talking with "gateway.sandbox.push.apple.com" instead of
+"gateway.push.apple.com". Default is true.
+
+=head2 ioloop
+
+  $self = $self->ioloop(Mojo::IOLoop->new);
+  $ioloop = $self->ioloop;
+
+Holds a L<Mojo::IOLoop> object.
+
+=head1 METHODS
+
+=head2 on
+
+Same as L<Mojo::EventEmitter/on>, but will also set up feedback connection if
+the event is L</feedback>.
+
+=head2 send
+
+  $self->send($device, $message, %args);
+  $self->send($device, $message, %args, sub { my ($self, $err) = @_; });
+
+Will send a C<$message> to the C<$device>. C<%args> is optional, but can contain:
+
+C<$cb> will be called when the messsage has been sent or if it could not be
+sent. C<$err> will be false on success.
+
+=over 4
+
+=item * badge
+
+The number placed on the app icon. Default is 0.
+
+=item * sound
+
+Default is "default".
+
+=item * Custom arguments
+
+=back
+
 =head1 AUTHOR
 
 Glen Hinkle - C<tempire@cpan.org>
@@ -299,5 +338,3 @@ Glen Hinkle - C<tempire@cpan.org>
 Jan Henning Thorsen - C<jhthorsen@cpan.org>
 
 =cut
-
-1;
